CustomParser class

author:郑再红 email:1096877329@qq.com date: 2022/12/7 time: 13:51 describe: 没做解析,外部需要自定义RouteParser A minimal parser that forwards RouteInformation unchanged. Use this when you do not need path parsing or parameter extraction.

Inheritance

Constructors

CustomParser()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseRouteInformation(RouteInformation routeInformation) Future<RouteInformation>
Converts the given route information into parsed data to pass to a RouterDelegate.
override
parseRouteInformationWithDependencies(RouteInformation routeInformation, BuildContext context) Future<RouteInformation>
Converts the given route information into parsed data to pass to a RouterDelegate.
inherited
restoreRouteInformation(RouteInformation configuration) RouteInformation
Restore the route information from the given configuration.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited