DrawerConfig class

author:郑再红 email:1096877329@qq.com date:2026-04-30 10:00 describe: 抽屉路由配置 用于配置抽屉路由栈的行为(不包含样式配置) Configures drawer stack behavior.

Constructors

DrawerConfig({bool autoOpen = true, bool autoClose = true, bool isEndDrawer = true})
const

Properties

autoClose bool
是否自动关闭抽屉(栈为空时) Whether to close the drawer automatically when only the root page remains.
final
autoOpen bool
是否自动打开抽屉(首次 push 时) Whether to open the drawer automatically when the stack becomes active.
final
hashCode int
The hash code for this object.
no setterinherited
isEndDrawer bool
是否为右侧抽屉(endDrawer) true: 右侧抽屉(endDrawer) false: 左侧抽屉(drawer) Whether this controller manages Scaffold.endDrawer instead of drawer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? autoOpen, bool? autoClose, bool? isEndDrawer}) DrawerConfig
复制并修改配置 Creates a copy with the provided fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited