autoClose property
是否自动关闭抽屉(栈为空时) Whether to close the drawer automatically when only the root page remains.
Implementation
final bool autoClose;
是否自动关闭抽屉(栈为空时) Whether to close the drawer automatically when only the root page remains.
final bool autoClose;