autoOpen property
是否自动打开抽屉(首次 push 时) Whether to open the drawer automatically when the stack becomes active.
Implementation
final bool autoOpen;
是否自动打开抽屉(首次 push 时) Whether to open the drawer automatically when the stack becomes active.
final bool autoOpen;