routerProxy property
底层的 RouterProxy 实例,管理页面栈 The router instance that owns the drawer page stack.
Implementation
final RouterProxy routerProxy;
底层的 RouterProxy 实例,管理页面栈 The router instance that owns the drawer page stack.
final RouterProxy routerProxy;