patterns property
路由模式列表 用于匹配和解析路径参数 Route patterns used to match and extract path parameters.
Implementation
final List<RoutePattern>? patterns;
路由模式列表 用于匹配和解析路径参数 Route patterns used to match and extract path parameters.
final List<RoutePattern>? patterns;