wrapper/visibility_detector library

Classes

RenderSliverVisibilityDetector
The RenderObject corresponding to the SliverVisibilityDetector widget.
RenderVisibilityDetector
The RenderObject corresponding to the VisibilityDetector widget.
SliverVisibilityDetector
A sliver version of VisibilityDetector.
VisibilityDetector
author:郑再红 email:1096877329@qq.com date: 2023/12/22 time: 14:17 describe:监听Widget/Sliver当前的可见度
VisibilityDetectorController
A VisibilityDetectorController is a singleton object that can perform actions and change configuration for all VisibilityDetector widgets.
VisibilityDetectorLayer
The Layer corresponding to a VisibilityDetector widget.
VisibilityInfo
Data passed to the VisibilityDetector.onVisibilityChanged callback.

Typedefs

VisibilityChangedCallback = void Function(VisibilityInfo info)
Signature for a callback to be invoked when the visibility of a widget changes.